@@ -18,15 +18,11 @@
 # along with OpenCDK; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-srcdir="$1"
-if [ -z "$srcdir" ] ; then
-	srcdir=`dirname "$0"`
-fi
 rm -f opencdk-api.html
 cd ..
 cd src
-for i in `ls "$srcdir/*.c"`; do
+for i in `ls *.c`; do
     echo -n "creating documentation for...$i "
-    $srcdir/gdoc -html $i >> ../doc/opencdk-api.html
+    ../doc/gdoc -html $i >> ../doc/opencdk-api.html
     echo "ok"
 done
