@@ -37,7 +37,7 @@
 
 #ifndef HAVE_U32_TYPEDEF
 # undef u32
-  typedef unsigned long u32;
+  typedef unsigned int u32;
 # define HAVE_U32_TYPEDEF
 #endif
 
